@@ -11,7 +11,6 @@ from airflow.version import version as airflow_version
 
 import dbnd_airflow
 
-from dbnd._core.utils.json_utils import flatten_dict
 from dbnd._core.utils.uid_utils import get_airflow_instance_uid
 from dbnd_airflow.export_plugin.compat import get_api_mode
 from dbnd_airflow.export_plugin.dag_operations import (
@@ -59,7 +58,7 @@ def safe_rich_result(f):
                 result.error_message = str(e)
             finally:
                 result.airflow_export_meta = get_meta(metrics)
-                return result
+            return result
 
     return wrapped
 
@@ -69,7 +68,7 @@ def get_meta(metrics):
 
     meta = AirflowExportMeta(
         airflow_version=airflow_version,
-        plugin_version=" ".join([dbnd_airflow.__version__, "v2"]),
+        plugin_version=dbnd_airflow.__version__,
         airflow_instance_uid=get_airflow_instance_uid(),
         api_mode=get_api_mode(),
         request_args=dict(flask.request.args) if flask.has_request_context() else {},
@@ -230,10 +229,6 @@ def remove_place_holders(dbnd_response):
             dbnd_response.pop("core", None)
 
 
-def is_subset(subset, superset):
-    return not (flatten_dict(subset).items() <= flatten_dict(superset).items())
-
-
 def get_or_create_db_connection(airflow_connection_from_hook, session):
     existing_db_connection = (
         session.query(Connection)
@@ -255,9 +250,6 @@ def check_syncer_config_and_set(dbnd_response, session=None):
     airflow_response = airflow_connection_from_hook.extra_dejson
     remove_place_holders(dbnd_response)
 
-    if not is_subset(dbnd_response, airflow_response):
-        return AirflowExportData()
-
     deep_update(airflow_response, dbnd_response)
 
     # A connection in Airflow can be set from the UI (saved in the DB) or from an environment variable (not in the db)
